#include <QtGui/QApplication>
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QCoreApplication::setOrganizationName("TedvdB");
    QCoreApplication::setOrganizationDomain("peejseej.nl");
    QCoreApplication::setApplicationName("MaemoSab");

    MainWindow w;
#if defined(Q_WS_S60)
    w.showMaximized();
#else
    w.show();
#endif

    if(argc==2)
    {
        w.uploadFileCommand(argv[1]);
    }

    return a.exec();
}
